@@ -284,7 +284,7 @@ public:
         It allows your app to receive progress updates during a lengthy POST operation. If you
         want to continue the operation, this should return true, or false to abort.
     */
-    typedef bool (OpenStreamProgressCallback) (void* context, int bytesSent, int totalBytes);
+    using OpenStreamProgressCallback = bool (void* context, int bytesSent, int totalBytes);
 
     /** Attempts to open a stream that can read from this URL.
 
@@ -347,7 +347,7 @@ public:
 
     //==============================================================================
     /** Represents a download task.
-        Returned by downloadToFile to allow querying and controling the download task.
+        Returned by downloadToFile to allow querying and controlling the download task.
     */
     class DownloadTask
     {
@@ -464,7 +464,7 @@ public:
         If it fails, or if the text that it reads can't be parsed as XML, this will
         return nullptr.
 
-        When it returns a valid XmlElement object, the caller is responsibile for deleting
+        When it returns a valid XmlElement object, the caller is responsible for deleting
         this object when no longer needed.
 
         Note that on some platforms (Android, for example) it's not permitted to do any network
@@ -526,6 +526,7 @@ private:
     StringArray parameterNames, parameterValues;
 
     static File fileFromFileSchemeURL (const URL&);
+    String getDomainInternal (bool) const;
 
     struct Upload  : public ReferenceCountedObject
     {
@@ -537,7 +538,6 @@ private:
         JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (Upload)
     };
 
-    friend struct ContainerDeletePolicy<Upload>;
     ReferenceCountedArray<Upload> filesToUpload;
 
   #if JUCE_IOS
