@@ -1,5 +1,5 @@
 /* GMM (C) 2018 Stephane Charette <stephanecharette@gmail.com>
- * $Id: GMMTypes.hpp 2637 2018-10-16 05:55:54Z stephane $
+ * $Id: GMMTypes.hpp 2640 2018-10-18 08:35:21Z stephane $
  */
 
 #pragma once
@@ -16,7 +16,10 @@
 #include <map>
 #include <cmath>
 #include <set>
+#include <list>
 #include <vector>
+#include <iomanip>
+#include <fstream>
 
 #include <ciso646>
 #include <cstdlib>
@@ -37,3 +40,4 @@ typedef int HANDLE;
 typedef std::set	<std::string>	SStr;
 typedef std::vector	<std::string>	VStr;
 typedef std::vector	<uint8_t>		VBytes;
+typedef std::list	<double>		LDouble;
