@@ -30,6 +30,9 @@ void Notebook::currentTabChanged(int newCurrentTabIndex, const String & newCurre
 		{
 			canvas->tab_is_active = true;
 			setTabBackgroundColour(idx, active_background);
+
+			// force an immediate update so the chart is redrawn
+			canvas->periodic_update();
 		}
 		else
 		{
